Learn R Programming

datarobot (version 2.18.9)

SaveCABundlePreference: Save the CA bundle path to the session environment variable.

Description

When caBundle is non-NULL, validates that it is a single character string pointing to an existing file, then writes it to CURL_CA_BUNDLE. When NULL, the function is a no-op, preserving any pre-existing value of CURL_CA_BUNDLE (which allows users to set the variable before starting R and have it picked up automatically).

Usage

SaveCABundlePreference(caBundle)

Arguments

caBundle

character or NULL. Path to a PEM-encoded CA bundle file.