When caBundle is non-NULL, validates that it is a single character string pointing
to an existing file, then writes it to CURL_CA_BUNDLE. When NULL, the function
is a no-op, preserving any pre-existing value of CURL_CA_BUNDLE (which allows
users to set the variable before starting R and have it picked up automatically).
SaveCABundlePreference(caBundle)character or NULL. Path to a PEM-encoded CA bundle file.